@@ -24,6 +24,7 @@ def clear():
 		os.system("clear")
 
 def prompt(return_type=str):
+	"""Get user input"""
 	error = None
 	try:
 		return return_type(input())
@@ -33,7 +34,13 @@ def prompt(return_type=str):
 		raise error
 
 def get_width():
+	"""Get the width of the terminal"""
 	return os.get_terminal_size().columns
 
+def get_height():
+	"""Get the height of the terminal"""
+	return os.get_terminal_size().lines
+
 def colour(ansi_colour):
+	"""Add an ansi-modifier / colour to the terminal"""
 	write(f"\u001b[{ansi_colour}m")
